@@ -11,3 +11,8 @@ class UnsupportedMapToException(Exception):
 # Txt File handler exceptions
 class TxtAutoModeException(Exception):
     pass
+
+
+# Exception for when map file is not found
+class MapFileNotFoundException(Exception):
+    pass
